# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/user_location_view.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/user_location_view.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\025UserLocationViewProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n@google/ads/googleads_v2/proto/resources/user_location_view.proto\x12!google.ads.googleads.v2.resources\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\x9c\x01\n\x10UserLocationView\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\x39\n\x14\x63ountry_criterion_id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x36\n\x12targeting_location\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x82\x02\n%com.google.ads.googleads.v2.resourcesB\x15UserLocationViewProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_USERLOCATIONVIEW = _descriptor.Descriptor(
  name='UserLocationView',
  full_name='google.ads.googleads.v2.resources.UserLocationView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.UserLocationView.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='country_criterion_id', full_name='google.ads.googleads.v2.resources.UserLocationView.country_criterion_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='targeting_location', full_name='google.ads.googleads.v2.resources.UserLocationView.targeting_location', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=322,
)

_USERLOCATIONVIEW.fields_by_name['country_criterion_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_USERLOCATIONVIEW.fields_by_name['targeting_location'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
DESCRIPTOR.message_types_by_name['UserLocationView'] = _USERLOCATIONVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserLocationView = _reflection.GeneratedProtocolMessageType('UserLocationView', (_message.Message,), dict(
  DESCRIPTOR = _USERLOCATIONVIEW,
  __module__ = 'google.ads.googleads_v2.proto.resources.user_location_view_pb2'
  ,
  __doc__ = """A user location view.
  
  User Location View includes all metrics aggregated at the country level,
  one row per country. It reports metrics at the actual physical location
  of the user by targeted or not targeted location. If other segment
  fields are used, you may get more than one row per country.
  
  
  Attributes:
      resource_name:
          The resource name of the user location view. UserLocation view
          resource names have the form:  ``customers/{customer_id}/userL
          ocationViews/{country_criterion_id}~{targeting_location}``
      country_criterion_id:
          Criterion Id for the country.
      targeting_location:
          Indicates whether location was targeted or not.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.UserLocationView)
  ))
_sym_db.RegisterMessage(UserLocationView)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/shared_criterion.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import criteria_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2
from google.ads.google_ads.v2.proto.enums import criterion_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_criterion__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/shared_criterion.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\024SharedCriterionProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n>google/ads/googleads_v2/proto/resources/shared_criterion.proto\x12!google.ads.googleads.v2.resources\x1a\x33google/ads/googleads_v2/proto/common/criteria.proto\x1a\x38google/ads/googleads_v2/proto/enums/criterion_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xb1\x05\n\x0fSharedCriterion\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\x30\n\nshared_set\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x31\n\x0c\x63riterion_id\x18\x1a \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12L\n\x04type\x18\x04 \x01(\x0e\x32>.google.ads.googleads.v2.enums.CriterionTypeEnum.CriterionType\x12>\n\x07keyword\x18\x03 \x01(\x0b\x32+.google.ads.googleads.v2.common.KeywordInfoH\x00\x12I\n\ryoutube_video\x18\x05 \x01(\x0b\x32\x30.google.ads.googleads.v2.common.YouTubeVideoInfoH\x00\x12M\n\x0fyoutube_channel\x18\x06 \x01(\x0b\x32\x32.google.ads.googleads.v2.common.YouTubeChannelInfoH\x00\x12\x42\n\tplacement\x18\x07 \x01(\x0b\x32-.google.ads.googleads.v2.common.PlacementInfoH\x00\x12T\n\x13mobile_app_category\x18\x08 \x01(\x0b\x32\x35.google.ads.googleads.v2.common.MobileAppCategoryInfoH\x00\x12S\n\x12mobile_application\x18\t \x01(\x0b\x32\x35.google.ads.googleads.v2.common.MobileApplicationInfoH\x00\x42\x0b\n\tcriterionB\x81\x02\n%com.google.ads.googleads.v2.resourcesB\x14SharedCriterionProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_criterion__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_SHAREDCRITERION = _descriptor.Descriptor(
  name='SharedCriterion',
  full_name='google.ads.googleads.v2.resources.SharedCriterion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.SharedCriterion.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shared_set', full_name='google.ads.googleads.v2.resources.SharedCriterion.shared_set', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='criterion_id', full_name='google.ads.googleads.v2.resources.SharedCriterion.criterion_id', index=2,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v2.resources.SharedCriterion.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='google.ads.googleads.v2.resources.SharedCriterion.keyword', index=4,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='youtube_video', full_name='google.ads.googleads.v2.resources.SharedCriterion.youtube_video', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='youtube_channel', full_name='google.ads.googleads.v2.resources.SharedCriterion.youtube_channel', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='placement', full_name='google.ads.googleads.v2.resources.SharedCriterion.placement', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mobile_app_category', full_name='google.ads.googleads.v2.resources.SharedCriterion.mobile_app_category', index=8,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mobile_application', full_name='google.ads.googleads.v2.resources.SharedCriterion.mobile_application', index=9,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='criterion', full_name='google.ads.googleads.v2.resources.SharedCriterion.criterion',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=275,
  serialized_end=964,
)

_SHAREDCRITERION.fields_by_name['shared_set'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_SHAREDCRITERION.fields_by_name['criterion_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SHAREDCRITERION.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_criterion__type__pb2._CRITERIONTYPEENUM_CRITERIONTYPE
_SHAREDCRITERION.fields_by_name['keyword'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._KEYWORDINFO
_SHAREDCRITERION.fields_by_name['youtube_video'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._YOUTUBEVIDEOINFO
_SHAREDCRITERION.fields_by_name['youtube_channel'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._YOUTUBECHANNELINFO
_SHAREDCRITERION.fields_by_name['placement'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._PLACEMENTINFO
_SHAREDCRITERION.fields_by_name['mobile_app_category'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._MOBILEAPPCATEGORYINFO
_SHAREDCRITERION.fields_by_name['mobile_application'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_criteria__pb2._MOBILEAPPLICATIONINFO
_SHAREDCRITERION.oneofs_by_name['criterion'].fields.append(
  _SHAREDCRITERION.fields_by_name['keyword'])
_SHAREDCRITERION.fields_by_name['keyword'].containing_oneof = _SHAREDCRITERION.oneofs_by_name['criterion']
_SHAREDCRITERION.oneofs_by_name['criterion'].fields.append(
  _SHAREDCRITERION.fields_by_name['youtube_video'])
_SHAREDCRITERION.fields_by_name['youtube_video'].containing_oneof = _SHAREDCRITERION.oneofs_by_name['criterion']
_SHAREDCRITERION.oneofs_by_name['criterion'].fields.append(
  _SHAREDCRITERION.fields_by_name['youtube_channel'])
_SHAREDCRITERION.fields_by_name['youtube_channel'].containing_oneof = _SHAREDCRITERION.oneofs_by_name['criterion']
_SHAREDCRITERION.oneofs_by_name['criterion'].fields.append(
  _SHAREDCRITERION.fields_by_name['placement'])
_SHAREDCRITERION.fields_by_name['placement'].containing_oneof = _SHAREDCRITERION.oneofs_by_name['criterion']
_SHAREDCRITERION.oneofs_by_name['criterion'].fields.append(
  _SHAREDCRITERION.fields_by_name['mobile_app_category'])
_SHAREDCRITERION.fields_by_name['mobile_app_category'].containing_oneof = _SHAREDCRITERION.oneofs_by_name['criterion']
_SHAREDCRITERION.oneofs_by_name['criterion'].fields.append(
  _SHAREDCRITERION.fields_by_name['mobile_application'])
_SHAREDCRITERION.fields_by_name['mobile_application'].containing_oneof = _SHAREDCRITERION.oneofs_by_name['criterion']
DESCRIPTOR.message_types_by_name['SharedCriterion'] = _SHAREDCRITERION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SharedCriterion = _reflection.GeneratedProtocolMessageType('SharedCriterion', (_message.Message,), dict(
  DESCRIPTOR = _SHAREDCRITERION,
  __module__ = 'google.ads.googleads_v2.proto.resources.shared_criterion_pb2'
  ,
  __doc__ = """A criterion belonging to a shared set.
  
  
  Attributes:
      resource_name:
          The resource name of the shared criterion. Shared set resource
          names have the form:  ``customers/{customer_id}/sharedCriteria
          /{shared_set_id}~{criterion_id}``
      shared_set:
          The shared set to which the shared criterion belongs.
      criterion_id:
          The ID of the criterion.  This field is ignored for mutates.
      type:
          The type of the criterion.
      criterion:
          The criterion.  Exactly one must be set.
      keyword:
          Keyword.
      youtube_video:
          YouTube Video.
      youtube_channel:
          YouTube Channel.
      placement:
          Placement.
      mobile_app_category:
          Mobile App Category.
      mobile_application:
          Mobile application.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.SharedCriterion)
  ))
_sym_db.RegisterMessage(SharedCriterion)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/feed_item_target.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.common import criteria_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_criteria__pb2
from google.ads.google_ads.v1.proto.enums import feed_item_target_device_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_feed__item__target__device__pb2
from google.ads.google_ads.v1.proto.enums import feed_item_target_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_feed__item__target__type__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/feed_item_target.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\023FeedItemTargetProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\n>google/ads/googleads_v1/proto/resources/feed_item_target.proto\x12!google.ads.googleads.v1.resources\x1a\x33google/ads/googleads_v1/proto/common/criteria.proto\x1a\x41google/ads/googleads_v1/proto/enums/feed_item_target_device.proto\x1a?google/ads/googleads_v1/proto/enums/feed_item_target_type.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\x8d\x05\n\x0e\x46\x65\x65\x64ItemTarget\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12/\n\tfeed_item\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12g\n\x15\x66\x65\x65\x64_item_target_type\x18\x03 \x01(\x0e\x32H.google.ads.googleads.v1.enums.FeedItemTargetTypeEnum.FeedItemTargetType\x12\x38\n\x13\x66\x65\x65\x64_item_target_id\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\x08\x63\x61mpaign\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x12\x30\n\x08\x61\x64_group\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x12>\n\x07keyword\x18\x07 \x01(\x0b\x32+.google.ads.googleads.v1.common.KeywordInfoH\x00\x12;\n\x13geo_target_constant\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x12^\n\x06\x64\x65vice\x18\t \x01(\x0e\x32L.google.ads.googleads.v1.enums.FeedItemTargetDeviceEnum.FeedItemTargetDeviceH\x00\x12\x45\n\x0b\x61\x64_schedule\x18\n \x01(\x0b\x32..google.ads.googleads.v1.common.AdScheduleInfoH\x00\x42\x08\n\x06targetB\x80\x02\n%com.google.ads.googleads.v1.resourcesB\x13\x46\x65\x65\x64ItemTargetProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_criteria__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_feed__item__target__device__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_feed__item__target__type__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_FEEDITEMTARGET = _descriptor.Descriptor(
  name='FeedItemTarget',
  full_name='google.ads.googleads.v1.resources.FeedItemTarget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.FeedItemTarget.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_item', full_name='google.ads.googleads.v1.resources.FeedItemTarget.feed_item', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_item_target_type', full_name='google.ads.googleads.v1.resources.FeedItemTarget.feed_item_target_type', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_item_target_id', full_name='google.ads.googleads.v1.resources.FeedItemTarget.feed_item_target_id', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign', full_name='google.ads.googleads.v1.resources.FeedItemTarget.campaign', index=4,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_group', full_name='google.ads.googleads.v1.resources.FeedItemTarget.ad_group', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword', full_name='google.ads.googleads.v1.resources.FeedItemTarget.keyword', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_constant', full_name='google.ads.googleads.v1.resources.FeedItemTarget.geo_target_constant', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='google.ads.googleads.v1.resources.FeedItemTarget.device', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ad_schedule', full_name='google.ads.googleads.v1.resources.FeedItemTarget.ad_schedule', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='target', full_name='google.ads.googleads.v1.resources.FeedItemTarget.target',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=349,
  serialized_end=1002,
)

_FEEDITEMTARGET.fields_by_name['feed_item'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEMTARGET.fields_by_name['feed_item_target_type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_feed__item__target__type__pb2._FEEDITEMTARGETTYPEENUM_FEEDITEMTARGETTYPE
_FEEDITEMTARGET.fields_by_name['feed_item_target_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEEDITEMTARGET.fields_by_name['campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEMTARGET.fields_by_name['ad_group'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEMTARGET.fields_by_name['keyword'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_criteria__pb2._KEYWORDINFO
_FEEDITEMTARGET.fields_by_name['geo_target_constant'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEMTARGET.fields_by_name['device'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_feed__item__target__device__pb2._FEEDITEMTARGETDEVICEENUM_FEEDITEMTARGETDEVICE
_FEEDITEMTARGET.fields_by_name['ad_schedule'].message_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_common_dot_criteria__pb2._ADSCHEDULEINFO
_FEEDITEMTARGET.oneofs_by_name['target'].fields.append(
  _FEEDITEMTARGET.fields_by_name['campaign'])
_FEEDITEMTARGET.fields_by_name['campaign'].containing_oneof = _FEEDITEMTARGET.oneofs_by_name['target']
_FEEDITEMTARGET.oneofs_by_name['target'].fields.append(
  _FEEDITEMTARGET.fields_by_name['ad_group'])
_FEEDITEMTARGET.fields_by_name['ad_group'].containing_oneof = _FEEDITEMTARGET.oneofs_by_name['target']
_FEEDITEMTARGET.oneofs_by_name['target'].fields.append(
  _FEEDITEMTARGET.fields_by_name['keyword'])
_FEEDITEMTARGET.fields_by_name['keyword'].containing_oneof = _FEEDITEMTARGET.oneofs_by_name['target']
_FEEDITEMTARGET.oneofs_by_name['target'].fields.append(
  _FEEDITEMTARGET.fields_by_name['geo_target_constant'])
_FEEDITEMTARGET.fields_by_name['geo_target_constant'].containing_oneof = _FEEDITEMTARGET.oneofs_by_name['target']
_FEEDITEMTARGET.oneofs_by_name['target'].fields.append(
  _FEEDITEMTARGET.fields_by_name['device'])
_FEEDITEMTARGET.fields_by_name['device'].containing_oneof = _FEEDITEMTARGET.oneofs_by_name['target']
_FEEDITEMTARGET.oneofs_by_name['target'].fields.append(
  _FEEDITEMTARGET.fields_by_name['ad_schedule'])
_FEEDITEMTARGET.fields_by_name['ad_schedule'].containing_oneof = _FEEDITEMTARGET.oneofs_by_name['target']
DESCRIPTOR.message_types_by_name['FeedItemTarget'] = _FEEDITEMTARGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedItemTarget = _reflection.GeneratedProtocolMessageType('FeedItemTarget', (_message.Message,), dict(
  DESCRIPTOR = _FEEDITEMTARGET,
  __module__ = 'google.ads.googleads_v1.proto.resources.feed_item_target_pb2'
  ,
  __doc__ = """A feed item target.
  
  
  Attributes:
      resource_name:
          The resource name of the feed item target. Feed item target
          resource names have the form:  ``customers/{customer_id}/feedI
          temTargets/{feed_id}~{feed_item_id}~{feed_item_target_type}~{f
          eed_item_target_id}``
      feed_item:
          The feed item to which this feed item target belongs.
      feed_item_target_type:
          The target type of this feed item target. This field is read-
          only.
      feed_item_target_id:
          The ID of the targeted resource. This field is read-only.
      target:
          The targeted resource.
      campaign:
          The targeted campaign.
      ad_group:
          The targeted ad group.
      keyword:
          The targeted keyword.
      geo_target_constant:
          The targeted geo target constant resource name.
      device:
          The targeted device.
      ad_schedule:
          The targeted schedule.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.FeedItemTarget)
  ))
_sym_db.RegisterMessage(FeedItemTarget)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Copyright 2018 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from __future__ import absolute_import
import importlib
import sys

from google.ads.google_ads import util


if sys.version_info < (3, 7):
    raise ImportError('This module requires Python 3.7 or later.')


_lazy_name_to_package_map = dict(
    types='google.ads.google_ads.v2',
    account_budget_proposal_service_client='google.ads.google_ads.v2.services',
    account_budget_service_client='google.ads.google_ads.v2.services',
    ad_group_ad_asset_view_service_client='google.ads.google_ads.v2.services',
    ad_group_ad_label_service_client='google.ads.google_ads.v2.services',
    ad_group_ad_service_client='google.ads.google_ads.v2.services',
    ad_group_audience_view_service_client='google.ads.google_ads.v2.services',
    ad_group_bid_modifier_service_client='google.ads.google_ads.v2.services',
    ad_group_criterion_label_service_client='google.ads.google_ads.v2.services',
    ad_group_criterion_service_client='google.ads.google_ads.v2.services',
    ad_group_criterion_simulation_service_client='google.ads.google_ads.v2.services',
    ad_group_extension_setting_service_client='google.ads.google_ads.v2.services',
    ad_group_feed_service_client='google.ads.google_ads.v2.services',
    ad_group_label_service_client='google.ads.google_ads.v2.services',
    ad_group_service_client='google.ads.google_ads.v2.services',
    ad_group_simulation_service_client='google.ads.google_ads.v2.services',
    ad_parameter_service_client='google.ads.google_ads.v2.services',
    ad_schedule_view_service_client='google.ads.google_ads.v2.services',
    ad_service_client='google.ads.google_ads.v2.services',
    age_range_view_service_client='google.ads.google_ads.v2.services',
    asset_service_client='google.ads.google_ads.v2.services',
    bidding_strategy_service_client='google.ads.google_ads.v2.services',
    billing_setup_service_client='google.ads.google_ads.v2.services',
    campaign_audience_view_service_client='google.ads.google_ads.v2.services',
    campaign_bid_modifier_service_client='google.ads.google_ads.v2.services',
    campaign_budget_service_client='google.ads.google_ads.v2.services',
    campaign_criterion_service_client='google.ads.google_ads.v2.services',
    campaign_criterion_simulation_service_client='google.ads.google_ads.v2.services',
    campaign_draft_service_client='google.ads.google_ads.v2.services',
    campaign_experiment_service_client='google.ads.google_ads.v2.services',
    campaign_extension_setting_service_client='google.ads.google_ads.v2.services',
    campaign_feed_service_client='google.ads.google_ads.v2.services',
    campaign_label_service_client='google.ads.google_ads.v2.services',
    campaign_service_client='google.ads.google_ads.v2.services',
    campaign_shared_set_service_client='google.ads.google_ads.v2.services',
    carrier_constant_service_client='google.ads.google_ads.v2.services',
    change_status_service_client='google.ads.google_ads.v2.services',
    click_view_service_client='google.ads.google_ads.v2.services',
    conversion_action_service_client='google.ads.google_ads.v2.services',
    conversion_adjustment_upload_service_client='google.ads.google_ads.v2.services',
    conversion_upload_service_client='google.ads.google_ads.v2.services',
    customer_client_link_service_client='google.ads.google_ads.v2.services',
    customer_client_service_client='google.ads.google_ads.v2.services',
    customer_extension_setting_service_client='google.ads.google_ads.v2.services',
    customer_feed_service_client='google.ads.google_ads.v2.services',
    customer_label_service_client='google.ads.google_ads.v2.services',
    customer_manager_link_service_client='google.ads.google_ads.v2.services',
    customer_negative_criterion_service_client='google.ads.google_ads.v2.services',
    customer_service_client='google.ads.google_ads.v2.services',
    custom_interest_service_client='google.ads.google_ads.v2.services',
    detail_placement_view_service_client='google.ads.google_ads.v2.services',
    display_keyword_view_service_client='google.ads.google_ads.v2.services',
    distance_view_service_client='google.ads.google_ads.v2.services',
    domain_category_service_client='google.ads.google_ads.v2.services',
    dynamic_search_ads_search_term_view_service_client='google.ads.google_ads.v2.services',
    enums='google.ads.google_ads.v2.services',
    expanded_landing_page_view_service_client='google.ads.google_ads.v2.services',
    extension_feed_item_service_client='google.ads.google_ads.v2.services',
    feed_item_service_client='google.ads.google_ads.v2.services',
    feed_item_target_service_client='google.ads.google_ads.v2.services',
    feed_mapping_service_client='google.ads.google_ads.v2.services',
    feed_placeholder_view_service_client='google.ads.google_ads.v2.services',
    feed_service_client='google.ads.google_ads.v2.services',
    gender_view_service_client='google.ads.google_ads.v2.services',
    geographic_view_service_client='google.ads.google_ads.v2.services',
    geo_target_constant_service_client='google.ads.google_ads.v2.services',
    google_ads_field_service_client='google.ads.google_ads.v2.services',
    google_ads_service_client='google.ads.google_ads.v2.services',
    group_placement_view_service_client='google.ads.google_ads.v2.services',
    hotel_group_view_service_client='google.ads.google_ads.v2.services',
    hotel_performance_view_service_client='google.ads.google_ads.v2.services',
    invoice_service_client='google.ads.google_ads.v2.services',
    keyword_plan_ad_group_service_client='google.ads.google_ads.v2.services',
    keyword_plan_campaign_service_client='google.ads.google_ads.v2.services',
    keyword_plan_idea_service_client='google.ads.google_ads.v2.services',
    keyword_plan_keyword_service_client='google.ads.google_ads.v2.services',
    keyword_plan_negative_keyword_service_client='google.ads.google_ads.v2.services',
    keyword_plan_service_client='google.ads.google_ads.v2.services',
    keyword_view_service_client='google.ads.google_ads.v2.services',
    label_service_client='google.ads.google_ads.v2.services',
    landing_page_view_service_client='google.ads.google_ads.v2.services',
    language_constant_service_client='google.ads.google_ads.v2.services',
    location_view_service_client='google.ads.google_ads.v2.services',
    managed_placement_view_service_client='google.ads.google_ads.v2.services',
    media_file_service_client='google.ads.google_ads.v2.services',
    merchant_center_link_service_client='google.ads.google_ads.v2.services',
    mobile_app_category_constant_service_client='google.ads.google_ads.v2.services',
    mobile_device_constant_service_client='google.ads.google_ads.v2.services',
    mutate_job_service_client='google.ads.google_ads.v2.services',
    operating_system_version_constant_service_client='google.ads.google_ads.v2.services',
    paid_organic_search_term_view_service_client='google.ads.google_ads.v2.services',
    parental_status_view_service_client='google.ads.google_ads.v2.services',
    payments_account_service_client='google.ads.google_ads.v2.services',
    product_bidding_category_constant_service_client='google.ads.google_ads.v2.services',
    product_group_view_service_client='google.ads.google_ads.v2.services',
    reach_plan_service_client='google.ads.google_ads.v2.services',
    recommendation_service_client='google.ads.google_ads.v2.services',
    remarketing_action_service_client='google.ads.google_ads.v2.services',
    search_term_view_service_client='google.ads.google_ads.v2.services',
    shared_criterion_service_client='google.ads.google_ads.v2.services',
    shared_set_service_client='google.ads.google_ads.v2.services',
    shopping_performance_view_service_client='google.ads.google_ads.v2.services',
    topic_constant_service_client='google.ads.google_ads.v2.services',
    topic_view_service_client='google.ads.google_ads.v2.services',
    user_interest_service_client='google.ads.google_ads.v2.services',
    user_list_service_client='google.ads.google_ads.v2.services',
    user_location_view_service_client='google.ads.google_ads.v2.services',
    video_service_client='google.ads.google_ads.v2.services',
    account_budget_proposal_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    account_budget_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    ad_group_ad_asset_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    ad_group_ad_label_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    ad_group_ad_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    ad_group_audience_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    ad_group_bid_modifier_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    ad_group_criterion_label_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    ad_group_criterion_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    ad_group_criterion_simulation_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    ad_group_extension_setting_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    ad_group_feed_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    ad_group_label_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    ad_group_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    ad_group_simulation_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    ad_parameter_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    ad_schedule_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    ad_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    age_range_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    asset_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    bidding_strategy_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    billing_setup_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    campaign_audience_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    campaign_bid_modifier_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    campaign_budget_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    campaign_criterion_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    campaign_criterion_simulation_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    campaign_draft_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    campaign_experiment_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    campaign_extension_setting_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    campaign_feed_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    campaign_label_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    campaign_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    campaign_shared_set_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    carrier_constant_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    change_status_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    click_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    conversion_action_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    conversion_adjustment_upload_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    conversion_upload_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    customer_client_link_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    customer_client_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    customer_extension_setting_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    customer_feed_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    customer_label_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    customer_manager_link_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    customer_negative_criterion_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    customer_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    custom_interest_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    detail_placement_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    display_keyword_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    distance_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    domain_category_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    dynamic_search_ads_search_term_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    expanded_landing_page_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    extension_feed_item_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    feed_item_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    feed_item_target_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    feed_mapping_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    feed_placeholder_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    feed_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    gender_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    geographic_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    geo_target_constant_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    google_ads_field_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    google_ads_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    group_placement_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    hotel_group_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    hotel_performance_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    invoice_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    keyword_plan_ad_group_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    keyword_plan_campaign_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    keyword_plan_idea_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    keyword_plan_keyword_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    keyword_plan_negative_keyword_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    keyword_plan_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    keyword_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    label_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    landing_page_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    language_constant_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    location_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    managed_placement_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    media_file_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    merchant_center_link_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    mobile_app_category_constant_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    mobile_device_constant_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    mutate_job_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    operating_system_version_constant_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    paid_organic_search_term_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    parental_status_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    payments_account_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    product_bidding_category_constant_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    product_group_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    reach_plan_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    recommendation_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    remarketing_action_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    search_term_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    shared_criterion_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    shared_set_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    shopping_performance_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    topic_constant_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    topic_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    user_interest_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    user_list_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    user_location_view_service_grpc_transport='google.ads.google_ads.v2.services.transports',
    video_service_grpc_transport='google.ads.google_ads.v2.services.transports',
)


# Background on how this behaves: https://www.python.org/dev/peps/pep-0562/
def __getattr__(name):  # Requires Python >= 3.7
    """Lazily perform imports and class definitions on first demand."""
    if name == '__all__':
        converted = (util.convert_snake_case_to_upper_case(key) for
                     key in _lazy_name_to_package_map)
        all_names = sorted(converted)
        globals()['__all__'] = all_names
        return all_names
    elif name.endswith('Transport'):
        module = __getattr__(util.convert_upper_case_to_snake_case(name))
        sub_mod_class = getattr(module, name)
        klass = type(name, (sub_mod_class,), {'__doc__': sub_mod_class.__doc__})
        globals()[name] = klass
        return klass
    elif name.endswith('ServiceClient'):
        module = __getattr__(util.convert_upper_case_to_snake_case(name))
        enums = __getattr__('enums')
        sub_mod_class = getattr(module, name)
        klass = type(name, (sub_mod_class,),
                     {'__doc__': sub_mod_class.__doc__, 'enums': enums})
        globals()[name] = klass
        return klass
    elif name in _lazy_name_to_package_map:
        module = importlib.import_module(f'{_lazy_name_to_package_map[name]}.{name}')
        globals()[name] = module
        return module
    else:
        raise AttributeError(f'unknown sub-module {name!r}.')


def __dir__():
    return globals().get('__all__') or __getattr__('__all__')



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/services/keyword_plan_idea_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import keyword_plan_common_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_keyword__plan__common__pb2
from google.ads.google_ads.v2.proto.enums import keyword_plan_network_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_keyword__plan__network__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/services/keyword_plan_idea_service.proto',
  package='google.ads.googleads.v2.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v2.servicesB\033KeywordPlanIdeaServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V2.Services\312\002 Google\\Ads\\GoogleAds\\V2\\Services\352\002$Google::Ads::GoogleAds::V2::Services'),
  serialized_pb=_b('\nFgoogle/ads/googleads_v2/proto/services/keyword_plan_idea_service.proto\x12 google.ads.googleads.v2.services\x1a>google/ads/googleads_v2/proto/common/keyword_plan_common.proto\x1a>google/ads/googleads_v2/proto/enums/keyword_plan_network.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x17google/api/client.proto\"\xe9\x03\n\x1bGenerateKeywordIdeasRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12.\n\x08language\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12:\n\x14geo_target_constants\x18\x08 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x66\n\x14keyword_plan_network\x18\t \x01(\x0e\x32H.google.ads.googleads.v2.enums.KeywordPlanNetworkEnum.KeywordPlanNetwork\x12S\n\x14keyword_and_url_seed\x18\x02 \x01(\x0b\x32\x33.google.ads.googleads.v2.services.KeywordAndUrlSeedH\x00\x12\x45\n\x0ckeyword_seed\x18\x03 \x01(\x0b\x32-.google.ads.googleads.v2.services.KeywordSeedH\x00\x12=\n\x08url_seed\x18\x05 \x01(\x0b\x32).google.ads.googleads.v2.services.UrlSeedH\x00\x42\x06\n\x04seed\"n\n\x11KeywordAndUrlSeed\x12)\n\x03url\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\x08keywords\x18\x02 \x03(\x0b\x32\x1c.google.protobuf.StringValue\"=\n\x0bKeywordSeed\x12.\n\x08keywords\x18\x01 \x03(\x0b\x32\x1c.google.protobuf.StringValue\"4\n\x07UrlSeed\x12)\n\x03url\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"k\n\x1bGenerateKeywordIdeaResponse\x12L\n\x07results\x18\x01 \x03(\x0b\x32;.google.ads.googleads.v2.services.GenerateKeywordIdeaResult\"\xa3\x01\n\x19GenerateKeywordIdeaResult\x12*\n\x04text\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Z\n\x14keyword_idea_metrics\x18\x03 \x01(\x0b\x32<.google.ads.googleads.v2.common.KeywordPlanHistoricalMetrics2\x8b\x02\n\x16KeywordPlanIdeaService\x12\xd3\x01\n\x14GenerateKeywordIdeas\x12=.google.ads.googleads.v2.services.GenerateKeywordIdeasRequest\x1a=.google.ads.googleads.v2.services.GenerateKeywordIdeaResponse\"=\x82\xd3\xe4\x93\x02\x37\"2/v2/customers/{customer_id=*}:generateKeywordIdeas:\x01*\x1a\x1b\xca\x41\x18googleads.googleapis.comB\x82\x02\n$com.google.ads.googleads.v2.servicesB\x1bKeywordPlanIdeaServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V2.Services\xca\x02 Google\\Ads\\GoogleAds\\V2\\Services\xea\x02$Google::Ads::GoogleAds::V2::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_keyword__plan__common__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_keyword__plan__network__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_client__pb2.DESCRIPTOR,])




_GENERATEKEYWORDIDEASREQUEST = _descriptor.Descriptor(
  name='GenerateKeywordIdeasRequest',
  full_name='google.ads.googleads.v2.services.GenerateKeywordIdeasRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.GenerateKeywordIdeasRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='google.ads.googleads.v2.services.GenerateKeywordIdeasRequest.language', index=1,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_target_constants', full_name='google.ads.googleads.v2.services.GenerateKeywordIdeasRequest.geo_target_constants', index=2,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_plan_network', full_name='google.ads.googleads.v2.services.GenerateKeywordIdeasRequest.keyword_plan_network', index=3,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_and_url_seed', full_name='google.ads.googleads.v2.services.GenerateKeywordIdeasRequest.keyword_and_url_seed', index=4,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_seed', full_name='google.ads.googleads.v2.services.GenerateKeywordIdeasRequest.keyword_seed', index=5,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_seed', full_name='google.ads.googleads.v2.services.GenerateKeywordIdeasRequest.url_seed', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='seed', full_name='google.ads.googleads.v2.services.GenerateKeywordIdeasRequest.seed',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=324,
  serialized_end=813,
)


_KEYWORDANDURLSEED = _descriptor.Descriptor(
  name='KeywordAndUrlSeed',
  full_name='google.ads.googleads.v2.services.KeywordAndUrlSeed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='google.ads.googleads.v2.services.KeywordAndUrlSeed.url', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keywords', full_name='google.ads.googleads.v2.services.KeywordAndUrlSeed.keywords', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=815,
  serialized_end=925,
)


_KEYWORDSEED = _descriptor.Descriptor(
  name='KeywordSeed',
  full_name='google.ads.googleads.v2.services.KeywordSeed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keywords', full_name='google.ads.googleads.v2.services.KeywordSeed.keywords', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=927,
  serialized_end=988,
)


_URLSEED = _descriptor.Descriptor(
  name='UrlSeed',
  full_name='google.ads.googleads.v2.services.UrlSeed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url', full_name='google.ads.googleads.v2.services.UrlSeed.url', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=990,
  serialized_end=1042,
)


_GENERATEKEYWORDIDEARESPONSE = _descriptor.Descriptor(
  name='GenerateKeywordIdeaResponse',
  full_name='google.ads.googleads.v2.services.GenerateKeywordIdeaResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v2.services.GenerateKeywordIdeaResponse.results', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1044,
  serialized_end=1151,
)


_GENERATEKEYWORDIDEARESULT = _descriptor.Descriptor(
  name='GenerateKeywordIdeaResult',
  full_name='google.ads.googleads.v2.services.GenerateKeywordIdeaResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='google.ads.googleads.v2.services.GenerateKeywordIdeaResult.text', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyword_idea_metrics', full_name='google.ads.googleads.v2.services.GenerateKeywordIdeaResult.keyword_idea_metrics', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1154,
  serialized_end=1317,
)

_GENERATEKEYWORDIDEASREQUEST.fields_by_name['language'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GENERATEKEYWORDIDEASREQUEST.fields_by_name['geo_target_constants'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GENERATEKEYWORDIDEASREQUEST.fields_by_name['keyword_plan_network'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_keyword__plan__network__pb2._KEYWORDPLANNETWORKENUM_KEYWORDPLANNETWORK
_GENERATEKEYWORDIDEASREQUEST.fields_by_name['keyword_and_url_seed'].message_type = _KEYWORDANDURLSEED
_GENERATEKEYWORDIDEASREQUEST.fields_by_name['keyword_seed'].message_type = _KEYWORDSEED
_GENERATEKEYWORDIDEASREQUEST.fields_by_name['url_seed'].message_type = _URLSEED
_GENERATEKEYWORDIDEASREQUEST.oneofs_by_name['seed'].fields.append(
  _GENERATEKEYWORDIDEASREQUEST.fields_by_name['keyword_and_url_seed'])
_GENERATEKEYWORDIDEASREQUEST.fields_by_name['keyword_and_url_seed'].containing_oneof = _GENERATEKEYWORDIDEASREQUEST.oneofs_by_name['seed']
_GENERATEKEYWORDIDEASREQUEST.oneofs_by_name['seed'].fields.append(
  _GENERATEKEYWORDIDEASREQUEST.fields_by_name['keyword_seed'])
_GENERATEKEYWORDIDEASREQUEST.fields_by_name['keyword_seed'].containing_oneof = _GENERATEKEYWORDIDEASREQUEST.oneofs_by_name['seed']
_GENERATEKEYWORDIDEASREQUEST.oneofs_by_name['seed'].fields.append(
  _GENERATEKEYWORDIDEASREQUEST.fields_by_name['url_seed'])
_GENERATEKEYWORDIDEASREQUEST.fields_by_name['url_seed'].containing_oneof = _GENERATEKEYWORDIDEASREQUEST.oneofs_by_name['seed']
_KEYWORDANDURLSEED.fields_by_name['url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDANDURLSEED.fields_by_name['keywords'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_KEYWORDSEED.fields_by_name['keywords'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_URLSEED.fields_by_name['url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GENERATEKEYWORDIDEARESPONSE.fields_by_name['results'].message_type = _GENERATEKEYWORDIDEARESULT
_GENERATEKEYWORDIDEARESULT.fields_by_name['text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_GENERATEKEYWORDIDEARESULT.fields_by_name['keyword_idea_metrics'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_keyword__plan__common__pb2._KEYWORDPLANHISTORICALMETRICS
DESCRIPTOR.message_types_by_name['GenerateKeywordIdeasRequest'] = _GENERATEKEYWORDIDEASREQUEST
DESCRIPTOR.message_types_by_name['KeywordAndUrlSeed'] = _KEYWORDANDURLSEED
DESCRIPTOR.message_types_by_name['KeywordSeed'] = _KEYWORDSEED
DESCRIPTOR.message_types_by_name['UrlSeed'] = _URLSEED
DESCRIPTOR.message_types_by_name['GenerateKeywordIdeaResponse'] = _GENERATEKEYWORDIDEARESPONSE
DESCRIPTOR.message_types_by_name['GenerateKeywordIdeaResult'] = _GENERATEKEYWORDIDEARESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GenerateKeywordIdeasRequest = _reflection.GeneratedProtocolMessageType('GenerateKeywordIdeasRequest', (_message.Message,), dict(
  DESCRIPTOR = _GENERATEKEYWORDIDEASREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.keyword_plan_idea_service_pb2'
  ,
  __doc__ = """Request message for [KeywordIdeaService.GenerateKeywordIdeas][].
  
  
  Attributes:
      customer_id:
          The ID of the customer with the recommendation.
      language:
          The resource name of the language to target. Required
      geo_target_constants:
          The resource names of the location to target. Max 10
      keyword_plan_network:
          Targeting network.
      seed:
          The type of seed to generate keyword ideas.
      keyword_and_url_seed:
          A Keyword and a specific Url to generate ideas from e.g. cars,
          www.example.com/cars.
      keyword_seed:
          A Keyword or phrase to generate ideas from, e.g. cars.
      url_seed:
          A specific url to generate ideas from, e.g.
          www.example.com/cars.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GenerateKeywordIdeasRequest)
  ))
_sym_db.RegisterMessage(GenerateKeywordIdeasRequest)

KeywordAndUrlSeed = _reflection.GeneratedProtocolMessageType('KeywordAndUrlSeed', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDANDURLSEED,
  __module__ = 'google.ads.googleads_v2.proto.services.keyword_plan_idea_service_pb2'
  ,
  __doc__ = """Keyword And Url Seed
  
  
  Attributes:
      url:
          The URL to crawl in order to generate keyword ideas.
      keywords:
          Requires at least one keyword.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.KeywordAndUrlSeed)
  ))
_sym_db.RegisterMessage(KeywordAndUrlSeed)

KeywordSeed = _reflection.GeneratedProtocolMessageType('KeywordSeed', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDSEED,
  __module__ = 'google.ads.googleads_v2.proto.services.keyword_plan_idea_service_pb2'
  ,
  __doc__ = """Keyword Seed
  
  
  Attributes:
      keywords:
          Requires at least one keyword.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.KeywordSeed)
  ))
_sym_db.RegisterMessage(KeywordSeed)

UrlSeed = _reflection.GeneratedProtocolMessageType('UrlSeed', (_message.Message,), dict(
  DESCRIPTOR = _URLSEED,
  __module__ = 'google.ads.googleads_v2.proto.services.keyword_plan_idea_service_pb2'
  ,
  __doc__ = """Url Seed
  
  
  Attributes:
      url:
          The URL to crawl in order to generate keyword ideas.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.UrlSeed)
  ))
_sym_db.RegisterMessage(UrlSeed)

GenerateKeywordIdeaResponse = _reflection.GeneratedProtocolMessageType('GenerateKeywordIdeaResponse', (_message.Message,), dict(
  DESCRIPTOR = _GENERATEKEYWORDIDEARESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.keyword_plan_idea_service_pb2'
  ,
  __doc__ = """Response message for [KeywordIdeaService.GenerateKeywordIdeas][].
  
  
  Attributes:
      results:
          Results of generating keyword ideas.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GenerateKeywordIdeaResponse)
  ))
_sym_db.RegisterMessage(GenerateKeywordIdeaResponse)

GenerateKeywordIdeaResult = _reflection.GeneratedProtocolMessageType('GenerateKeywordIdeaResult', (_message.Message,), dict(
  DESCRIPTOR = _GENERATEKEYWORDIDEARESULT,
  __module__ = 'google.ads.googleads_v2.proto.services.keyword_plan_idea_service_pb2'
  ,
  __doc__ = """The result of generating keyword ideas.
  
  
  Attributes:
      text:
          Text of the keyword idea. As in Keyword Plan historical
          metrics, this text may not be an actual keyword, but the
          canonical form of multiple keywords. See
          KeywordPlanKeywordHistoricalMetrics message in
          KeywordPlanService.
      keyword_idea_metrics:
          The historical metrics for the keyword
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GenerateKeywordIdeaResult)
  ))
_sym_db.RegisterMessage(GenerateKeywordIdeaResult)


DESCRIPTOR._options = None

_KEYWORDPLANIDEASERVICE = _descriptor.ServiceDescriptor(
  name='KeywordPlanIdeaService',
  full_name='google.ads.googleads.v2.services.KeywordPlanIdeaService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\312A\030googleads.googleapis.com'),
  serialized_start=1320,
  serialized_end=1587,
  methods=[
  _descriptor.MethodDescriptor(
    name='GenerateKeywordIdeas',
    full_name='google.ads.googleads.v2.services.KeywordPlanIdeaService.GenerateKeywordIdeas',
    index=0,
    containing_service=None,
    input_type=_GENERATEKEYWORDIDEASREQUEST,
    output_type=_GENERATEKEYWORDIDEARESPONSE,
    serialized_options=_b('\202\323\344\223\0027\"2/v2/customers/{customer_id=*}:generateKeywordIdeas:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_KEYWORDPLANIDEASERVICE)

DESCRIPTOR.services_by_name['KeywordPlanIdeaService'] = _KEYWORDPLANIDEASERVICE

# @@protoc_insertion_point(module_scope)
